==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/ContourValueResolverDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var ContourValueResolverDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ContourValueResolverDescriptionMetadata, _super);
    function ContourValueResolverDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ContourValueResolverDescriptionMetadata.b = function (a) {
        if (ContourValueResolverDescriptionMetadata.a == null) {
            ContourValueResolverDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ContourValueResolverDescriptionMetadata.c(ContourValueResolverDescriptionMetadata.a);
        }
        if (a.g(ContourValueResolverDescriptionMetadata.a)) {
            return;
        }
        a.s(ContourValueResolverDescriptionMetadata.a);
    };
    ContourValueResolverDescriptionMetadata.c = function (a) {
    };
    ContourValueResolverDescriptionMetadata.d = function (a) {
        ContourValueResolverDescriptionMetadata.b(a);
        a.t("ContourValueResolver", ContourValueResolverDescriptionMetadata.a);
    };
    ContourValueResolverDescriptionMetadata.$t = markType(ContourValueResolverDescriptionMetadata, 'ContourValueResolverDescriptionMetadata');
    ContourValueResolverDescriptionMetadata.a = null;
    return ContourValueResolverDescriptionMetadata;
}(Base));
export { ContourValueResolverDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ContourValueResolverDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var ContourValueResolverDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ContourValueResolverDescriptionMetadata, _super);
    function ContourValueResolverDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ContourValueResolverDescriptionMetadata.b = function (a) {
        if (ContourValueResolverDescriptionMetadata.a == null) {
            ContourValueResolverDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ContourValueResolverDescriptionMetadata.c(ContourValueResolverDescriptionMetadata.a);
        }
        if (a.j(ContourValueResolverDescriptionMetadata.a)) {
            return;
        }
        a.y(ContourValueResolverDescriptionMetadata.a);
    };
    ContourValueResolverDescriptionMetadata.c = function (a) {
    };
    ContourValueResolverDescriptionMetadata.d = function (a) {
        ContourValueResolverDescriptionMetadata.b(a);
        a.z("ContourValueResolver", ContourValueResolverDescriptionMetadata.a);
    };
    ContourValueResolverDescriptionMetadata.$t = markType(ContourValueResolverDescriptionMetadata, 'ContourValueResolverDescriptionMetadata');
    ContourValueResolverDescriptionMetadata.a = null;
    return ContourValueResolverDescriptionMetadata;
}(Base));
export { ContourValueResolverDescriptionMetadata };
